@@ -412,6 +412,8 @@ class Miniterm(object):
         self.update_transformations()
         self.exit_character = unichr(0x1d)  # GS/CTRL+]
         self.menu_character = unichr(0x14)  # Menu: CTRL+T
+        self.reboot_character = unichr(0x12)  # CTRL+R
+        self.start_character = unichr(0x06)  # CTRL+F
         self.alive = None
         self._reader_alive = None
         self.receiver_thread = None
@@ -543,6 +545,10 @@ class Miniterm(object):
                 elif c == self.exit_character:
                     self.stop()             # exit app
                     break
+                elif c == self.reboot_character:
+                    self.serial.write(self.tx_encoder.encode('kernel reboot cold\r\n\r\n'))
+                elif c == self.start_character:
+                    self.serial.write(self.tx_encoder.encode('sniffer start\r\n'))
                 else:
                     #~ if self.raw:
                     text = c
@@ -914,7 +920,7 @@ def main(default_port=None, default_baudrate=921600, default_rts=None, default_d
         choices=['CR', 'LF', 'CRLF'],
         type=lambda c: c.upper(),
         help='end of line mode',
-        default='LF')
+        default='CRLF')
 
     group.add_argument(
         '--raw',
